"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = useHtmlIframeProps;

var _reactNative = require("react-native");

var _reactNativeRenderHtml = require("react-native-render-html");

var _extractPrintDimensions = _interopRequireDefault(require("./extractPrintDimensions"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function normalizeUri(uri) {
  return uri.startsWith('//') ? "https:".concat(uri) : uri;
}

const defaultIframeConfig = {
  webViewProps: {
    allowsFullscreenVideo: true
  }
};
/**
 * Extract props for the HTMLIframe component from renderer function arguments.
 * This function is especially usefull for custom iframe renderers.
 *
 * @param props - The props of a custom block renderer.
 * @param iframeConfig - Override config options.
 *
 * @public
 */

function useHtmlIframeProps({
  key,
  style,
  tnode
}, iframeConfig) {
  const {
    WebView,
    onLinkPress,
    defaultWebViewProps,
    contentWidth,
    computeEmbeddedMaxWidth,
    renderersProps: {
      iframe: globalIframeConfig
    } = {}
  } = (0, _reactNativeRenderHtml.useSharedProps)();
  const resolvedConfig = { ...defaultIframeConfig,
    ...globalIframeConfig,
    ...iframeConfig,
    webViewProps: { ...defaultWebViewProps,
      ...defaultIframeConfig.webViewProps,
      ...(globalIframeConfig === null || globalIframeConfig === void 0 ? void 0 : globalIframeConfig.webViewProps),
      ...(iframeConfig === null || iframeConfig === void 0 ? void 0 : iframeConfig.webViewProps)
    }
  };
  const resolvedContentWidth = typeof contentWidth === 'number' ? contentWidth : _reactNative.Dimensions.get('window').width;
  const availableWidth = (computeEmbeddedMaxWidth === null || computeEmbeddedMaxWidth === void 0 ? void 0 : computeEmbeddedMaxWidth.call(null, resolvedContentWidth, 'iframe')) || resolvedContentWidth;
  const htmlAttribs = tnode.attributes;
  const {
    width,
    height,
    ...restStyle
  } = style;
  const attrWidth = Number(htmlAttribs.width);
  const attrHeight = Number(htmlAttribs.height);
  const printConfig = {
    attrWidth: Number.isNaN(attrWidth) ? null : attrWidth,
    attrHeight: Number.isNaN(attrHeight) ? null : attrHeight,
    styleWidth: typeof width === 'string' ? null : width,
    styleHeight: typeof height === 'string' ? null : height,
    contentWidth: availableWidth
  };
  const {
    printWidth,
    printHeight
  } = (0, _extractPrintDimensions.default)(printConfig);
  const scaleFactor = typeof printConfig.attrWidth === 'number' && printConfig.attrWidth > printWidth ? printWidth / attrWidth : 1;
  const source = htmlAttribs.srcdoc ? {
    html: htmlAttribs.srcdoc
  } : {
    uri: normalizeUri(htmlAttribs.src)
  };

  if (__DEV__ && !WebView) {
    console.warn("@native-html/iframe-plugin: You must pass a WebView component from react-native-webview as a prop to the HTML component. The iframe won't be rendered.");
  }

  return WebView ? { ...resolvedConfig,
    key,
    source,
    onLinkPress,
    htmlAttribs,
    scaleFactor,
    style: [restStyle, {
      width: printWidth,
      height: printHeight
    }],
    WebView
  } : null;
}
//# sourceMappingURL=useHtmlIframeProps.js.map